@@ -22,6 +22,11 @@
 #'    multistage designs where the first-stage sampling fractions are small (and can thus be ignored).
 #'    Accommodates stratified designs. All sampling within a stratum must be simple random sampling with or without replacement,
 #'    although the first-stage sampling is effectively treated as sampling without replacement.
+#'  \item \strong{"Antal-Tille"}: \cr
+#'    The doubled half bootstrap method proposed by Antal and Tillé (2014), which is only applicable to single-stage designs or
+#'    multistage designs where the first-stage sampling fractions are small (and can thus be ignored).
+#'    Accomodates stratified designs. Sampling within each stratum can be simple random sampling or unequal probability sampling
+#'    with or without replacement.
 #'  \item \strong{"Preston"}: \cr
 #'    Preston's multistage rescaled bootstrap, which is applicable to single-stage designs or multistage designs
 #'    with arbitrary sampling fractions. Accommodates stratified designs. All sampling within a stratum must be
@@ -59,7 +64,9 @@
 #' @seealso Use \code{\link[svrep]{estimate_boot_reps_for_target_cv}} to help choose the number of bootstrap replicates.
 #'
 #' The underlying function for the Rao-Wu-Yue-Beaumont bootstrap
-#' is \code{\link[svrep]{make_rwyb_bootstrap_weights}}.
+#' is \code{\link[svrep]{make_rwyb_bootstrap_weights}},
+#' and the underlying function for the Antal-Tillé bootstrap 
+#' is \code{\link[svrep]{make_doubled_half_bootstrap_weights}}.
 #' Other bootstrap methods are implemented using functions from the 'survey' package,
 #' including: \code{\link[survey]{bootweights}} (Canty-Davison),
 #' \code{\link[survey]{subbootweights}} (Rao-Wu),
@@ -70,9 +77,13 @@
 #' one can use the generalized survey bootstrap method. See \code{\link[svrep]{as_gen_boot_design}} or \code{\link[svrep]{make_gen_boot_factors}}.
 #'
 #' @references
+#' Antal, E. and Tillé, Y. (2014). 
+#' "A new resampling method for sampling designs without replacement: The doubled half bootstrap." 
+#' \strong{Computational Statistics}, \emph{29}(5), 1345-1363. https://doi.org/10.1007/s00180-014-0495-0
+#' 
 #' Beaumont, J.-F.; Émond, N. (2022).
 #' "A Bootstrap Variance Estimation Method for Multistage Sampling and Two-Phase Sampling When Poisson Sampling Is Used at the Second Phase."
-#' \strong{Stats}, \emph{5}: 339–357.
+#' \strong{Stats}, \emph{5}: 339-357.
 #' https://doi.org/10.3390/stats5020019
 #'
 #' Canty, A.J.; Davison, A.C. (1999).
@@ -85,7 +96,7 @@
 #'
 #' Rao, J.N.K.; Wu, C.F.J.; Yue, K. (1992).
 #' "Some recent work on resampling methods for complex surveys."
-#' \strong{Survey Methodology}, \emph{18}: 209–217.
+#' \strong{Survey Methodology}, \emph{18}: 209-217.
 #'
 #'
 #' @examples
@@ -168,10 +179,10 @@ as_bootstrap_design.survey.design <- function(design,
 
   type <- tolower(type)
   permissible_types <- c("rao-wu-yue-beaumont", "preston", "rao-wu",
-                         "canty-davison")
+                         "canty-davison", "antal-tille")
 
   if (is.null(type) || is.na(type) || (length(type) != 1) || !all(type %in% permissible_types)) {
-    stop("Invalid value of `type`. Must use either 'Rao-Wu-Yue-Beaumont', 'Preston', 'Rao-Wu', or 'Canty-Davison'.")
+    stop("Invalid value of `type`. Must use either 'Rao-Wu-Yue-Beaumont', 'Preston', 'Rao-Wu', 'Antal-Tille', or 'Canty-Davison'.")
   }
 
   if (type == "rao-wu-yue-beaumont") {
@@ -230,8 +241,31 @@ as_bootstrap_design.survey.design <- function(design,
     )
 
   }
+  
+  if (type == "antal-tille") {
+    
+    adjustment_factors <- make_doubled_half_bootstrap_weights(
+      num_replicates       = replicates,
+      samp_unit_ids        = design$cluster[, 1, drop = TRUE],
+      strata_ids           = design$strata[, 1, drop = TRUE],
+      samp_unit_sel_probs  = design$allprob[, 1, drop = TRUE],
+      output = "factors"
+    )
+    
+    rep_design <- survey::svrepdesign(
+      variables  = design$variables,
+      weights    = weights(design, type = "sampling"),
+      repweights = adjustment_factors, combined.weights = FALSE,
+      compress   = compress, 
+      mse        = mse,
+      scale      = 1/replicates, 
+      rscales    = rep(1, times = replicates),
+      type       = "bootstrap"
+    )
+    
+  }
 
-  if (type != "rao-wu-yue-beaumont") {
+  if (!type %in% c("rao-wu-yue-beaumont", "antal-tille")) {
     type <- switch(type,
                    'preston' = "mrbbootstrap",
                    'mrbootstrap' = "mrbootstrap",
