@@ -104,7 +104,7 @@
 #'
 #' Fay, Robert. 1989.
 #' "Theory And Application Of Replicate Weighting For Variance Calculations."
-#' In, 495–500. Alexandria, VA: American Statistical Association.
+#' In, 495-500. Alexandria, VA: American Statistical Association.
 #' http://www.asasrms.org/Proceedings/papers/1989_033.pdf
 #'
 #' @seealso Use \code{\link[svrep]{rescale_reps}} to eliminate negative adjustment factors.
@@ -373,30 +373,30 @@ make_fays_gen_rep_factors <- function(
 #' by using only a random subset of the replicates.
 #'
 #' - Ash, S. (2014). "\emph{Using successive difference replication for estimating variances}."
-#' \strong{Survey Methodology}, Statistics Canada, 40(1), 47–59.
+#' \strong{Survey Methodology}, Statistics Canada, 40(1), 47-59.
 #' \cr \cr
 #' - Beaumont, J.-F.; Émond, N. (2022).
 #' "\emph{A Bootstrap Variance Estimation Method for Multistage Sampling and Two-Phase Sampling When Poisson Sampling Is Used at the Second Phase}."
-#' \strong{Stats}, \emph{5}: 339–357.
+#' \strong{Stats}, \emph{5}: 339-357.
 #' https://doi.org/10.3390/stats5020019
 #' \cr \cr
 #' - Breidt, F. J., Opsomer, J. D., & Sanchez-Borrego, I. (2016). 
 #' "\emph{Nonparametric Variance Estimation Under Fine Stratification: An Alternative to Collapsed Strata}." 
-#' \strong{Journal of the American Statistical Association}, 111(514), 822–833. https://doi.org/10.1080/01621459.2015.1058264
+#' \strong{Journal of the American Statistical Association}, 111(514), 822-833. https://doi.org/10.1080/01621459.2015.1058264
 #' \cr \cr
-#' - Deville, J.‐C., and Tillé, Y. (2005). "\emph{Variance approximation under balanced sampling.}"
-#' \strong{Journal of Statistical Planning and Inference}, 128, 569–591.
+#' - Deville, J. C., and Tillé, Y. (2005). "\emph{Variance approximation under balanced sampling.}"
+#' \strong{Journal of Statistical Planning and Inference}, 128, 569-591.
 #' \cr \cr
-#' - Dippo, Cathryn, Robert Fay, and David Morganstein. 1984. “Computing Variances from Complex Samples with Replicate Weights.” In, 489–94. Alexandria, VA: American Statistical Association. http://www.asasrms.org/Proceedings/papers/1984_094.pdf.
+#' - Dippo, Cathryn, Robert Fay, and David Morganstein. 1984. "Computing Variances from Complex Samples with Replicate Weights." In, 489-94. Alexandria, VA: American Statistical Association. http://www.asasrms.org/Proceedings/papers/1984_094.pdf.
 #' \cr \cr
-#' - Fay, Robert. 1984. “Some Properties of Estimates of Variance Based on Replication Methods.” In, 495–500. Alexandria, VA: American Statistical Association. http://www.asasrms.org/Proceedings/papers/1984_095.pdf.
+#' - Fay, Robert. 1984. "Some Properties of Estimates of Variance Based on Replication Methods." In, 495-500. Alexandria, VA: American Statistical Association. http://www.asasrms.org/Proceedings/papers/1984_095.pdf.
 #' \cr \cr
-#' - Fay, Robert. 1989. “Theory And Application Of Replicate Weighting For Variance Calculations.” In, 495–500. Alexandria, VA: American Statistical Association. http://www.asasrms.org/Proceedings/papers/1989_033.pdf
+#' - Fay, Robert. 1989. "Theory And Application Of Replicate Weighting For Variance Calculations." In, 495-500. Alexandria, VA: American Statistical Association. http://www.asasrms.org/Proceedings/papers/1989_033.pdf
 #' \cr \cr
 #' - Matei, Alina, and Yves Tillé. (2005).
-#' “\emph{Evaluation of Variance Approximations and Estimators
-#' in Maximum Entropy Sampling with Unequal Probability and Fixed Sample Size.}”
-#' \strong{Journal of Official Statistics}, 21(4):543–70.
+#' "\emph{Evaluation of Variance Approximations and Estimators
+#' in Maximum Entropy Sampling with Unequal Probability and Fixed Sample Size.}"
+#' \strong{Journal of Official Statistics}, 21(4):543-70.
 #' @examples
 #' if (FALSE) {
 #'
@@ -450,7 +450,7 @@ as_fays_gen_rep_design.twophase2 <- function(design, variance_estimator = NULL,
                                              max_replicates = Inf,
                                              balanced = TRUE,
                                              psd_option = "warn",
-                                             mse = getOption("survey.replicates.mse"),
+                                             mse = TRUE,
                                              compress = TRUE) {
 
   Sigma <- get_design_quad_form(design, variance_estimator, aux_var_names = aux_var_names)
